<?php

class Class_v4_wp1crm_Extensions_oAuth
{
    public function __construct()
    {
        if (!defined('V4OAUTHPATH')) {
            return false;
        }

        add_action('admin_enqueue_scripts', [$this, 'admin_style']);

        /*
         * wp-admin
         */
        add_action('login_header', [$this, 'backend_login_start']);
        add_action('login_footer', [$this, 'backend_login_end']);

        /*
         * Events Manager
         */
        // disable EM register welcome mail
        add_filter('option_dbem_email_disable_registration', '__return_true');
        //replace login/register
        add_filter('option_dbem_bookings_login_form', '__return_true');
        add_filter('em_locate_template', [$this, 'relocate_em_templates'], 20, 4);

        /*
         * WooCommerce
         */
//      //disable woocommerce register
        add_filter('woocommerce_registration_auth_new_customer', '__return_false', 10, 2);
        add_filter('woocommerce_checkout_customer_id', [$this, 'check_new_user_on_checkout']);
        add_action('template_redirect', [$this, 'logout_new_user_on_checkout']);
        //replace login/register
        add_filter('wc_get_template', [$this, 'relocate_wc_templates'], 20, 5);
        add_filter(
            'woocommerce_registration_error_email_exists',
            [$this, 'woocommerce_registration_error_email_exists'],
            20,
            0
        );

        return $this;
    }

    public function backend_login_start()
    {
        ?>
    <div class="wpwh-container wpwh-container-loginRegister">
        <div class="wpwh-login">
            <p class="wpwh-login_signInPhrase"><b>Melde dich über 1CRM an:</b></p>
            <p class="wpwh-login_signInButton">
                <a class="button " href="/?connect=1crm&redirect_to=<?php echo urlencode(admin_url()) ?>">Anmelden</a>
            </p>
            <?php
            $v4_oauth_options = get_option('v4_oauth');
            if (!empty($v4_oauth_options['providers'])) {
                foreach ($v4_oauth_options['providers'] as $provider) {
                    ?>
                    <p>
                        <a class="oauth-provider oauth-provider--<?= $provider ?>"
                           href="/?connect=<?= $provider ?>&redirect_to=<?php echo urlencode(admin_url()) ?>"
                        >Sign in with <?= v4\wp\plugins\oauth\Settings::$providers[$provider] ?></a>
                    </p>
                    <?php
                }
            }
            ?>
            <br>
            <p>oder über WordPress:</p>
<!--            <p><a href="#" onclick="v4_be_toggle()">WordPress Admin</a></p>-->
        </div>
    </div>
<!--    <div id="v4_be_toggle_container">-->
            <?php
    }

    public function backend_login_end()
    {
        ?>
<!--    </div>-->
        <?php
        $plugin_dir_url = plugin_dir_url('');
        $css = $plugin_dir_url . 'v4-wp-webhook/public/css/v4-wp-webhook-public.css';
        $css_loading = $plugin_dir_url . 'v4-wp-webhook/public/css/v4-wp-webhook-public-loading.css';
        $jquery = $plugin_dir_url . 'v4-oauth/assets/js/jquery.3.7.0.js';
        ?>
    <link rel="stylesheet" href="<?= $css ?>">
    <link rel="stylesheet" href="<?= $css_loading ?>">
    <style>
        div.wpwh-container {
            display: flex;
            justify-content: center;
            align-items: center;
            flex-wrap: wrap;
            margin: 50px 0 0;
        }

        div.wpwh-login {
            text-align: center;
            margin-right: 0;
        }
        div.wpwh-login > p {
            margin-bottom: 10px;
        }
    </style>
    <script src="<?= $jquery ?>"></script>
    <script>
        // Show an element
        const show = function (elem) {
            elem.style.display = 'block';
        };

        // Hide an element
        const hide = function (elem) {
            elem.style.display = 'none';
        };

        // Toggle element visibility
        const toggle = function (elem) {

            // If the element is visible, hide it
            if (window.getComputedStyle(elem).display === 'block') {
                hide(elem);
                return;
            }

            // Otherwise, show it
            show(elem);

        };

        // toggle(document.getElementById('v4_be_toggle_container'));
        // const v4_be_toggle = function () {
        //     toggle(document.getElementById('v4_be_toggle_container'));
        // };

    </script>
        <?php
    }

    public function woocommerce_registration_error_email_exists()
    {
        $providers = '';
        $v4_oauth_options = get_option('v4_oauth');
        if (!empty($v4_oauth_options['providers'])) {
            foreach ($v4_oauth_options['providers'] as $provider) {
                ob_start();
                ?>
                <a class="button Button"
                   href="?connect=<?= $provider ?>">Sign in with <?= v4\wp\plugins\oauth\Settings::$providers[$provider] ?></a>
                <?php
                $providers .= ob_get_clean();
            }
        }

        return apply_filters(
            'woocommerce_checkout_login_message',
            esc_html__(
                'An account is already registered with your email address. ' .
                    'Please log in before proceeding.',
                'woocommerce'
            )
        )
            . $providers
            . '<a class="button Button" href="?connect=1crm">' . esc_html__('Login', 'v4-wp-webhook') . '</a>';
    }

    public function admin_style()
    {
        wp_enqueue_style(
            'v4_wp1crm_extensions_oauth_css',
            plugin_dir_url(__FILE__) . 'css/v4-wp1crm-extensions-admin-oauth.css',
            array(),
            '0.0.1',
            'all'
        );
    }

    public function relocate_em_templates($located, $template_name, $load, $the_args)
    {
        // child theme has priority
        $theme_located = locate_template(array('plugins/events-manager/' . $template_name));

        if ($theme_located) {
            $located = $theme_located;
        } else {
            switch ($template_name) {
                case 'forms/bookingform/login.php':
                    $located = __DIR__ . '/partials/oauth/em/forms/bookingform/login.php';
                    break;
                case 'templates/my-bookings.php':
                    // show oauth login, if not logged in
                    if (!is_user_logged_in()) {
                        $located = __DIR__ . '/partials/oauth/em/templates/my-bookings.php';
                    }
                    break;
            }
        }

        return $located;
    }

    public function em_booking_form_login()
    {
        include __DIR__ . '/partials/oauth/em/v4/em_booking_form_login.php';
    }

    public function em_booking_form_register()
    {
        include __DIR__ . '/partials/oauth/em/v4/em_booking_form_register.php';
    }

    public function em_booking_form_register_end()
    {
        include __DIR__ . '/partials/oauth/em/v4/em_booking_form_register_end.php';
    }

    public function relocate_wc_templates($template, $template_name, $args, $template_path, $default_path)
    {
        if (file_exists(get_stylesheet_directory() . '/' . WC()->template_path() . $template_name)) {
            $theme_file = get_stylesheet_directory() . '/' . WC()->template_path() . $template_name;
        } elseif (file_exists(get_template_directory() . '/' . WC()->template_path() . $template_name)) {
            $theme_file = get_template_directory() . '/' . WC()->template_path() . $template_name;
        } else {
            $theme_file = false;
        }

        if (empty($theme_file) && file_exists(__DIR__ . '/partials/oauth/wc/' . $template_name)) {
            $template = __DIR__ . '/partials/oauth/wc/' . $template_name;
        }

        return $template;
    }

    public function check_new_user_on_checkout($user_id)
    {
        if (empty($user_id)) {
            if (!session_id()) {
                session_start();
            }
            $_SESSION['wpwh']['checkout']['new_user'] = true;
        }

        return $user_id;
    }

    public function logout_new_user_on_checkout()
    {
        global $wp;
        if (isset($_SESSION['wpwh']['checkout']['new_user']) &&
            is_order_received_page() &&
            isset($wp->query_vars['order-received'])
        ) {
            unset($_SESSION['wpwh']['checkout']['new_user']);
            wp_clear_auth_cookie();
            wp_set_current_user(0);
        }
    }
}
