<?php
if (!defined('ABSPATH') || !current_user_can('manage_options')) die('wrong entry point');

function v4wp1crmGeneratePassword($passwordlength = 8,
                                  $numNonAlpha = 0,
                                  $numNumberChars = 0,
                                  $useCapitalLetter = false)
{

    $numberChars = '123456789';
    $specialChars = '!$%&=?*-:;.,+~@_';
    $secureChars = 'abcdefghjkmnpqrstuvwxyzABCDEFGHJKMNPQRSTUVWXYZ';

    // Stack für Password-Erzeugung füllen
    $stack = $secureChars;

    if ($useCapitalLetter)
        $stack .= strtoupper($secureChars);

    $count = $passwordlength - $numNonAlpha - $numNumberChars;
    $temp = str_shuffle($stack);
    $stack = substr($temp, 0, $count);

    if ($numNonAlpha > 0) {
        $temp = str_shuffle($specialChars);
        $stack .= substr($temp, 0, $numNonAlpha);
    }

    if ($numNumberChars > 0) {
        $temp = str_shuffle($numberChars);
        $stack .= substr($temp, 0, $numNumberChars);
    }

    // Rückgabe des erzeugten Passwortes
    return str_shuffle($stack);

}

$time_valid = 60 * 60 * 1000;
$errors = [];
$current_time = floor(microtime(true) * 1000);

if (isset($_POST['action']) && $_POST['action'] === 'wp1crm_allow_reset_settings') {
    update_option('wp1crm_allow_reset_settings', [
        'time' => $current_time,
        'url' => trim($_POST['wp1crm_reset_settings_1crm_url'], '/'),
        'secret' => $_POST['wp1crm_reset_settings_secret']
    ]);
}
$wp1crm_allow_reset_settings = get_option('wp1crm_allow_reset_settings');

?>
    <h2>wp1crm automatisch konfigurieren</h2>
    <p>
        Um wp1crm automatisch zu konfigurieren, muss auf beiden Seiten die jeweilige URL und ein Schlüssel hinterlegt
        werden. <br> Die Konfiguration ist nur eine Stunde gültig und muss sonst auf beiden Seiten noch einmal
        gespeichert werden.
    </p>
    <form method="post">
        <input type="hidden" name="action" value="wp1crm_allow_reset_settings">
        <table class="form-table">
            <tbody>
            <tr>
                <th scope="row">
                    <label for="wp1crm_reset_settings_1crm_url">1CRM URL</label>
                </th>
                <td>
                    <input type="text" id="wp1crm_reset_settings_1crm_url" name="wp1crm_reset_settings_1crm_url" value="<?= $wp1crm_allow_reset_settings['url'] ?>">
                </td>
            </tr>
            <tr>
                <th scope="row">
                    <label for="wp1crm_reset_settings_secret">neuer Schlüssel</label>
                </th>
                <td>
                    <input type="text" id="wp1crm_reset_settings_secret" name="wp1crm_reset_settings_secret"
                           value="<?php echo v4wp1crmGeneratePassword(16, 0, 4); ?>">
                    <p class="description">Muss mit dem Schlüssel im 1CRM übereinstimmen</p>
                </td>
            </tr>
            <tr>
                <td></td>
                <td>
                    <p class="submit">
                        <input type="submit" value="automatische Konfiguration erlauben" class="button">
                    </p>
                </td>
            </tr>
            </tbody>
        </table>
    </form>
<?php
if (isset($wp1crm_allow_reset_settings['time']) && $wp1crm_allow_reset_settings['time'] + $time_valid > $current_time) {
    ?>
    <p>Dein Schlüssel wurde gespeichert.</p>
    <pre><?= $wp1crm_allow_reset_settings['url'] ?></pre>
    <pre><?= $wp1crm_allow_reset_settings['secret'] ?></pre>
    <p>Gültigkeit: <span id="wp1crm_allow_reset_settings_timer"></span></p>
    <p>automatische Konfiguration muss aus dem <a href="<?= $wp1crm_allow_reset_settings['url'] ?>/index.php?module=v4WebHook_Config&action=reset_settings">1CRM</a> angestoßen werden.</p>
    <script>
        // Set the date we're counting down to
        let countDownDate = <?= $wp1crm_allow_reset_settings['time'] + $time_valid ?>;

        // Update the count down every 1 second
        let x = setInterval(function() {

            // Get today's date and time
            let now = new Date().getTime();

            // Find the distance between now and the count-down date
            let distance = countDownDate - now;

            // Time calculations for days, hours, minutes and seconds
            // let days = Math.floor(distance / (1000 * 60 * 60 * 24));
            let hours = Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
            let minutes = Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60));
            let seconds = Math.floor((distance % (1000 * 60)) / 1000);

            // Display the result in the element with id="wp1crm_allow_reset_settings_timer"
            document.getElementById("wp1crm_allow_reset_settings_timer").innerHTML = hours + "h "
                + minutes + "m " + seconds + "s ";

            // If the count-down is finished, write some text
            if (distance < 0) {
                clearInterval(x);
                document.getElementById("wp1crm_allow_reset_settings_timer").innerHTML = "EXPIRED";
            }
        }, 1000);
    </script>
    <?php
}